@@ -191,7 +191,7 @@ LM13=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                grafico,
+                "plot"=grafico,
                 "VIF"=vif)
-  print(graficos)
+  graficos
 }
