@@ -165,7 +165,7 @@ LM2i3=function(trat,
                                rmse))
   graficos=list("Coefficients"=models,
                 "values"=graphs,
-                grafico,
+                "plot"=grafico,
                 "VIF"=vif)
-  print(graficos)
+  graficos
 }
