@@ -164,6 +164,6 @@ asymptotic_i=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                graph)
-  print(graficos)
+                "plot"=graph)
+  graficos
 }
